@@ -5,7 +5,7 @@ from operator import itemgetter
 from string import punctuation
 from typing import Callable, Generator, Iterable, Match, Pattern, Union, Dict, Set
 
-import unidecode
+from anyascii import anyascii
 from num2words import num2words
 
 from text_scrubber.io import read_resource_file
@@ -278,15 +278,20 @@ class TextScrubber:
         """
         return self._add_step(name, lambda t: RE_STRIP_QUOTES.sub('', t), on_tokens)
 
-    def remove_stop_words(self, stop_words: Iterable[str] = None, name: str = 'remove_stop_words') -> 'TextScrubber':
+    def remove_stop_words(self, stop_words: Iterable[str] = None, name: str = 'remove_stop_words',
+                          case_sensitive: bool = False) -> 'TextScrubber':
         """
         Removes stop words. All-caps tokens are considered to be abbreviations and are retained.
 
+        :param case_sensitive: should the stopword removal be case_sensitive or not
         :param stop_words: Iterable of stop words to remove. If not provided it will use a default list of stop words.
         :param name: Name to give to the pipeline step.
         """
         stop_words_set = set(stop_words) if stop_words else STOP_WORDS
-        remove_func = partial(filter, lambda t: t.isupper() or t.lower() not in stop_words_set)
+        if not case_sensitive:
+            remove_func = partial(filter, lambda t: t.isupper() or t.lower() not in stop_words_set)
+        else:
+            remove_func = partial(filter, lambda t: t.isupper() or t not in stop_words_set)
         return self._add_step(name, remove_func, on_tokens=False)
 
     def remove_suffixes(self, suffixes: Set[str], on_tokens: bool = False,
@@ -375,12 +380,12 @@ class TextScrubber:
 
     def to_ascii(self, on_tokens: bool = False, name: str = 'to_ascii') -> 'TextScrubber':
         """
-        Uses ``unidecode.unidecode`` to strip accents and convert unicode characters to plain 7-bit ASCII.
+        Uses ``anyascii`` to strip accents and convert unicode characters to plain 7-bit ASCII.
 
         :param on_tokens: Whether to transform on a list of tokens or a single string.
         :param name: Name to give to the pipeline step.
         """
-        return self._add_step(name, unidecode.unidecode, on_tokens)
+        return self._add_step(name, anyascii, on_tokens)
 
     # Alias
     strip_accents = to_ascii
